<?php

/**
 * plugin_transactions_resas_teste_quotas_doc()
 * 
 * Ce plugin teste si la rservation d'un exemplaire donn est possible eu gard aux quotas de rservation du lecteur 
 * (nombre de rsas effectues par le lecteur sur les diffrents types de docs)
 * Ce test se base sur les infos de l'exemplaire (section, type doc...). Contrairement  la gestion des quotas de prt, on ne peut pas accder aux infos de la 
 * notice biblio, du lecteur... 
 * Par ailleurs, les infos de l'exemplaire sont dans un premier temps rcuprs dans les notices de resa (pour gnrer l'arbre), puis dans la notice exe
 * (pour tester si un exemplaire donn peut tre rserv). Comme ces informations (identiques) peuvent correspondre  des accs diffrents entre la notice 
 * de rsa et la notice exe, on aura 2 paramtres pour les critres : [criteres_resa] et [criteres_exe]
 * 
 * Ce test n'est  effectuer que pour le premier exemplaire d'une notice bibliographique (on assume que les exemplaires suivants auront les mmes critres : type doc, section...)
 * 
 * Le plugin commence par rcuprer les diffrents quotas dans le registre, ainsi que les critres (par ex. type doc et section)
 * On rcupre ensuite les infos sur les abonnements du lecteur : si ID_famille != "" on rcupre les quotas du chef de famill, sinon ceux de l'individu. A partir de l, on voit quels sont les quotas actifs du lecteur et on les fusionne
 * ce qui donne un arbre vierge
 * On rcupre ensuite la liste des rsas en cours du lecteur, ce qui va permettre de gnrer l'arbre  jour du lecteur
 * Pour finir, on teste la rsa de l'exemplaire  tester. a retourne un arbre  jour (si OK), une dure de rsa et ventuellement des erreurs 
 * 
 * @param [$exemplaire] // infos d'exemplaire sous la forme d'une ligne de la base de donnes
 * @param [$ID_lecteur]
 * @param [$ID_famille]
 * @param [$validation_message] // si "oui", forcer la rsa
 * @param [$plugin_get_infos_quotas=] // retourne [arbres] et [criteres]
 * @param [$plugin_get_abos] // retourne la liste des abonnements sous la forme de lignes de base de donnes
 * @param [$plugin_traite_abonnements]
 * @param [$plugin_get_resas] // retourne la liste des rsas sous la forme de lignes de base de donnes
 * @param [$plugin_resa_2_quota]
 * 
 * 
 * @return [arbre] => l'arbre maj
 * @return [duree] => dure de la rsa
 * @return [depassement] => message d'erreur en cas de dpassement (indiquant le quota qui a bloqu...)
 */
function plugin_transactions_resas_teste_quotas_doc ($parametres) {
    $retour=array();
    $retour["succes"]=1;
    $retour["resultat"]=array();
    
    
    $exemplaire=$parametres["exemplaire"]; // infos d'exemplaire sous la forme d'une ligne de la base de donnes
    $ID_lecteur=$parametres["ID_lecteur"];
    $ID_famille=$parametres["ID_famille"];
    $validation_message=$parametres["validation_message"];
    $plugin_get_infos_quotas=$parametres["plugin_get_infos_quotas"]; // retourne [arbres] et [criteres]
    $plugin_get_abos=$parametres["plugin_get_abos"]; // retourne la liste des abonnements sous la forme de lignes de base de donnes
    $plugin_traite_abonnements=$parametres["plugin_traite_abonnements"];
    $plugin_get_resas=$parametres["plugin_get_resas"]; // retourne la liste des rsas sous la forme de lignes de base de donnes
    $plugin_resa_2_quota=$parametres["plugin_resa_2_quota"];
    
    // 1) On rcupre les infos lies aux quotas et aux critres
    $tmp=applique_plugin($plugin_get_infos_quotas, array());
    if ($tmp["succes"] != 1) {
        $retour["succes"]=0;
        $retour["erreur"]="les informations de quotas ne sont pas parametrees";
        return ($retour);
    }
    $infos_quotas=$tmp["resultat"];
    //$arbres=$infos_quotas["arbres"];
    $criteres_resa=$infos_quotas["criteres_resa"]; // les critres  utiliser dans la notice de rsa (pour gnrer l'arbre)')
    $criteres_exe=$infos_quotas["criteres_exe"]; // les critres  utiliser dans la notice d'exemplaire une fois que l'arbre est gnr pour tester si l'exe est rservable
    
    // 2) On rcupre les abonnements (et codes quotas) en cours
    if ($ID_famille == "" OR $ID_famille == "0") {
        $ID_famille=$ID_lecteur;
    }
    $tmp=applique_plugin($plugin_get_abos, array("ID_lecteur"=>$ID_famille));
    if ($tmp["succes"] != 1) {
        return ($tmp);
    }
    $nb_abos=$tmp["resultat"]["nb_notices"];
    $abos=$tmp["resultat"]["notices"];
    
    // 3) On gnre un arbre des quotas vierge
    $tmp=applique_plugin($plugin_traite_abonnements, array("infos_abos"=>$abos, "infos_quotas"=>$infos_quotas));
    if ($tmp["succes"] != 1) {
        return ($tmp);
    }
    $messages=$tmp["resultat"]["messages"];
    $arbre=$tmp["resultat"]["arbre"];
    
    // 4) On rcupre la liste des rservations de ce lecteur
    $tmp=applique_plugin($plugin_get_resas, array("ID_lecteur"=>$ID_lecteur));
    if ($tmp["succes"] != 1) {
        return ($tmp);
    }
    $nb_resas=$tmp["resultat"]["nb_notices"];
    $resas=$tmp["resultat"]["notices"];
    
    // 5) On rcupre l'arbre dfinitif en faisant une maj pour chaque rsa
    foreach ($resas as $resa) {
        $tmp=applique_plugin($plugin_resa_2_quota, array("arbre"=>$arbre, "criteres"=>$criteres_resa, "validation_message"=>"oui", "bureau"=>$resa));
        if ($tmp["succes"] != 1) {
            return ($tmp);
        }
        $arbre=$tmp["resultat"]["arbre"]; // arbre  jour
    }
    
    // 6) On teste pour voir si la rsa de l'exemplaire est possible
    $tmp=applique_plugin($plugin_resa_2_quota, array("arbre"=>$arbre, "criteres"=>$criteres_exe, "validation_message"=>$validation_message, "bureau"=>$exemplaire));
    return($tmp);
}



?>